<?php
/*
Plugin Name: XYZ Theme
Description: XYZ Theme plugin allows users to authenticate their licenses and manage plugins & themes updates effortlessly.
Version: 1.5
Author: XYZ Theme
*/

require_once plugin_dir_path(__FILE__) . 'includes/gpl-update-checker.php';
global $gpl_updater;

// Define constants
define('GPL_AUTH_URL', 'https://www.xyztheme.com/updater/');
define('GPL_AUTH_AUTHENTICATE', GPL_AUTH_URL . 'authenticate.php');
define('GPL_AUTH_VALIDATE', GPL_AUTH_URL . 'validate_token.php');
define('GPL_AUTH_REVOKE', GPL_AUTH_URL . 'revoke_token.php');
define('GPL_AUTH_PACKAGE_DETAILS', GPL_AUTH_URL . 'get_package_details.php');

// Add menu item
function gpl_auth_menu() {
    add_menu_page('XYZ Theme', 'XYZ Theme', 'manage_options', 'gpl-auth', 'gpl_auth_page');
}
add_action('admin_menu', 'gpl_auth_menu');

// Remove WordPress notifications on the plugin page
function gpl_remove_notifications() {
    $screen = get_current_screen();
    if ($screen && $screen->id === 'toplevel_page_gpl-auth') {
        remove_all_actions('admin_notices');
        remove_all_actions('all_admin_notices');
    }
}
add_action('admin_head', 'gpl_remove_notifications');

// Enqueue styles
function gpl_auth_styles($hook) {
    if ($hook != 'toplevel_page_gpl-auth') {
        return;
    }
    wp_enqueue_style('gpl-auth-style', plugin_dir_url(__FILE__) . 'css/gpl-auth-style.css', array(), '1.5');
}
add_action('admin_enqueue_scripts', 'gpl_auth_styles');

// Function to get clean site URL
function gpl_get_clean_site_url($url) {
    // Remove protocol (http, https, etc.)
    $clean_url = preg_replace('(^https?://)', '', $url);
    
    // Remove trailing slash
    $clean_url = rtrim($clean_url, '/');
    
    return $clean_url;
}

// Get the current website's clean URL
function gpl_get_site_url() {
    return gpl_get_clean_site_url(get_site_url());
}

// Save token and expiry
function gpl_save_token($token, $expiry) {
    update_option('gpl_auth_token', $token);
    update_option('gpl_auth_token_expiry', $expiry);
}

// Get token
function gpl_get_token() {
    return get_option('gpl_auth_token');
}

// Get token expiry
function gpl_get_token_expiry() {
    return get_option('gpl_auth_token_expiry');
}

// Delete token and expiry
function gpl_delete_token() {
    delete_option('gpl_auth_token');
    delete_option('gpl_auth_token_expiry');
}

// Main authentication function
function gpl_authenticate($username, $password) {
    $response = wp_remote_post(GPL_AUTH_AUTHENTICATE, array(
        'body' => array(
            'username' => $username,
            'password' => $password,
            'site_url' => gpl_get_site_url()
        )
    ));

    if (is_wp_error($response)) {
        return false;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if ($data['status'] === 'success') {
        gpl_save_token($data['token'], $data['expiry']);
        update_option('gpl_auth_username', $username);
        
        do_action('gpl_after_authenticate');
        
        return true;
    }

    return false;
}

// Validate token function
function gpl_validate_token() {
    $token = gpl_get_token();
    $expiry = gpl_get_token_expiry();

    if (!$token || !$expiry) {
        return false;
    }

    if (strtotime($expiry) <= time()) {
        $response = wp_remote_post(GPL_AUTH_VALIDATE, array(
            'body' => array(
                'token' => $token,
                'site_url' => gpl_get_site_url()
            )
        ));

        if (is_wp_error($response)) {
            gpl_delete_token();
            return false;
        }

        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body, true);

        if ($data['status'] === 'success' && isset($data['token'])) {
            gpl_save_token($data['token'], $data['expiry']);
            return true;
        } else {
            gpl_delete_token();
            return false;
        }
    }

    return true;
}

// Disconnect function
function gpl_disconnect() {
    $token = gpl_get_token();
    if ($token) {
        wp_remote_post(GPL_AUTH_REVOKE, array(
            'body' => array(
                'token' => $token,
                'site_url' => gpl_get_site_url()
            )
        ));
    }
    gpl_delete_token();
    delete_option('gpl_auth_username');
}

// Initialize the GPL_Updater
if (!isset($gpl_updater) || !($gpl_updater instanceof GPL_Updater)) {
    $gpl_updater = new GPL_Updater();
}

// Run update check when authenticating
add_action('gpl_after_authenticate', array($gpl_updater, 'gpl_check_and_store_updates'));

// Include dashboard file
require_once plugin_dir_path(__FILE__) . 'includes/dashboard.php';

// Handle authentication form submission
if (isset($_POST['username']) && isset($_POST['password'])) {
    if (gpl_authenticate($_POST['username'], $_POST['password'])) {
        $is_connected = true;
        $username = $_POST['username'];
        $message = 'Successfully authenticated.';
        
        // Handle remember me functionality
        if (isset($_POST['remember_me'])) {
            $credentials = array(
                'username' => $_POST['username'],
                'password' => base64_encode($_POST['password'])
            );
            setcookie('gpl_auth_remember', json_encode($credentials), time() + (30 * 24 * 60 * 60), '/');
        }
    } else {
        $message = 'Authentication failed.';
    }
}