<?php
// Prevent direct access to this file
if (!defined('ABSPATH')) {
    exit;
}

function gpl_auth_page() {
    global $gpl_updater;
    
    $message = '';
    $is_connected = gpl_validate_token();
    $username = get_option('gpl_auth_username', '');
    
    if ($is_connected && isset($gpl_updater)) {
        $gpl_updater->gpl_check_and_store_updates();
    }
    
    if (!$is_connected && $username) {
        $message = 'Your session has expired. Please log in again.';
        gpl_disconnect();
        $username = '';
    }
    
    // Check for remembered credentials
    if (!$is_connected && isset($_COOKIE['gpl_auth_remember'])) {
        $credentials = json_decode(stripslashes($_COOKIE['gpl_auth_remember']), true);
        if ($credentials && isset($credentials['username']) && isset($credentials['password'])) {
            $password = base64_decode($credentials['password']);
            if (gpl_authenticate($credentials['username'], $password)) {
                $is_connected = true;
                $username = $credentials['username'];
                $message = 'Automatically logged in.';
            } else {
                setcookie('gpl_auth_remember', '', time() - 3600, '/');
            }
        }
    }
    
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        if (isset($_POST['disconnect'])) {
            gpl_disconnect();
            $is_connected = false;
            $username = '';
            $message = 'Successfully disconnected.';
        } elseif (isset($_POST['username']) && isset($_POST['password'])) {
            if (gpl_authenticate($_POST['username'], $_POST['password'])) {
                $is_connected = true;
                $username = $_POST['username'];
                $message = 'Successfully authenticated.';
            } else {
                $message = 'Authentication failed.';
            }
        }
    }
    
    ?>
    <div class="wrap gpl-auth-wrap">
        <div class="gpl-auth-container">
            <div class="gpl-auth-header">
                <h1>XYZ Theme Login</h1>
                <?php if (!$is_connected): ?>
                    <p class="gpl-auth-description">Log in to access your premium themes and updates</p>
                <?php endif; ?>
            </div>
            <?php if ($message): ?>
                <div class="gpl-auth-message"><?php echo esc_html($message); ?></div>
            <?php endif; ?>
            <form method="post" id="gpl-auth-form">
                <div class="gpl-form-group">
                    <label for="username">Username or Email</label>
                    <input type="text" name="username" id="username" value="<?php echo esc_attr($username); ?>" <?php echo $is_connected ? 'disabled' : ''; ?>>
                </div>
                <div class="gpl-form-group">
                    <label for="password">Password</label>
                    <input type="password" name="password" id="password" value="<?php echo $is_connected ? '********' : ''; ?>" <?php echo $is_connected ? 'disabled' : ''; ?>>
                </div>
                <?php if (!$is_connected): ?>
                    <div class="remember-me-wrapper">
                        <input type="checkbox" name="remember_me" id="remember-me">
                        <label for="remember-me">Remember Me</label>
                    </div>
                <?php endif; ?>
                <?php if ($is_connected): ?>
                    <input type="submit" name="disconnect" value="Disconnect" class="button button-primary">
                <?php else: ?>
                    <input type="submit" value="Log In" class="button button-primary">
                <?php endif; ?>
            </form>
            <div id="gpl-auth-status">
                <span id="gpl-connection-status" class="<?php echo $is_connected ? 'connected' : 'not-connected'; ?>">
                    <?php echo $is_connected ? 'Connected' : 'Not connected'; ?>
                </span>
            </div>
        </div>
    </div>
    <?php
}